﻿using System;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.WebEdition;
using System.Data;

public partial class _Default : System.Web.UI.Page, ICallbackEventHandler
{
        private string callbackResult = string.Empty;
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                string callbackString = ClientScript.GetCallbackEventReference(this, "args", "showToolTips", "context");
                string script = "var beginToolTipsRequest = function() { var lonlat = this.map.getLonLatFromViewPortPx(this.xy); var args = lonlat.lon + ',' + lonlat.lat + ',' + vScale; var context = $get('divTooltips');"
                    + callbackString
                    + "}";
                ClientScript.RegisterClientScriptBlock(GetType(), "BeginCallback", script, true);


                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
                Map1.MapUnit = GeographyUnit.Meter;

                //Create 2 shapelayers (1 point and 1 line layer)
                ShapeFileFeatureLayer lyr_points_Access_Point = new ShapeFileFeatureLayer(MapPath("~/Data/Access_Points.shp"));
                lyr_points_Access_Point.ZoomLevelSet.ZoomLevel18.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.SimpleColors.Blue, 12f);
                lyr_points_Access_Point.ZoomLevelSet.ZoomLevel18.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                lyr_points_Access_Point.DrawingMarginPercentage = 50;
                lyr_points_Access_Point.IsVisible = true;

                ShapeFileFeatureLayer lyr_lines_FS_LD = new ShapeFileFeatureLayer(Server.MapPath("~/Data/FS_LD.shp"));
                lyr_lines_FS_LD.ZoomLevelSet.ZoomLevel05.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Blue, 2.5f, true);
                lyr_lines_FS_LD.ZoomLevelSet.ZoomLevel05.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                lyr_lines_FS_LD.DrawingMarginPercentage = 50;
                lyr_lines_FS_LD.IsVisible = true;

                Proj4Projection proj4_points_Access_Points = new Proj4Projection();
                proj4_points_Access_Points.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj4_points_Access_Points.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                lyr_points_Access_Point.FeatureSource.Projection = proj4_points_Access_Points;

                Proj4Projection proj4_lines_FS_LD = new Proj4Projection();
                proj4_lines_FS_LD.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj4_lines_FS_LD.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                lyr_lines_FS_LD.FeatureSource.Projection = proj4_lines_FS_LD;

                LayerOverlay layerOverLay = new LayerOverlay("OSPFM Layers");
                layerOverLay.IsBaseOverlay = false;
                layerOverLay.ClientCache.CacheId = "OSPFM_Layers";
                layerOverLay.TransitionEffect = TransitionEffect.None;

                layerOverLay.Layers.Add("Lyr_Access_Point", lyr_points_Access_Point);
                layerOverLay.Layers.Add("Lyr_FS_LD", lyr_lines_FS_LD);

                //Create VE layer and to Map1
                VirtualEarthOverlay ve = new VirtualEarthOverlay("VirtualEarth Map");
                ve.VirtualEarthMapType = VirtualEarthMapType.Birdseye;

                Map1.CustomOverlays.Add(layerOverLay);
                Map1.CustomOverlays.Add(ve);
            }
        }

        #region ICallbackEventHandler Members

        public string GetCallbackResult()
        {
            return callbackResult;
        }

        public void RaiseCallbackEvent(string eventArgument)
        {  
            string[] lonlatStrings = eventArgument.Split(',');
            string[] iCurrentScale = eventArgument.Split(',');
            int iCurSacle = Convert.ToInt32(iCurrentScale[2]);
            System.Text.StringBuilder sb = new System.Text.StringBuilder();

            PointShape clickWorldPosition = new PointShape(double.Parse(lonlatStrings[0]), double.Parse(lonlatStrings[1]));

            // convert to screen point.
            ScreenPointF clickScreenPoint = Map1.ToScreenCoordinate(clickWorldPosition);

            // 5 is the radius to buffer the click point.
            double nextSPX = 0;

            if (iCurSacle >= 4 && iCurSacle <= 12)  // 4 to 12
            { nextSPX = clickScreenPoint.X + 5; }  // 5; 
            else if (iCurSacle >= 13 && iCurSacle <= 15) // 13 to 15
            { nextSPX = clickScreenPoint.X + 0.09;  } // 0.09;
            else if (iCurSacle >= 16 && iCurSacle <= 19) // 16 to 19
            { nextSPX = clickScreenPoint.X + 0.0009; } // 0.0009;

            ScreenPointF clickNextScreenPoint = new ScreenPointF(Convert.ToSingle(nextSPX), clickScreenPoint.Y);

            // calculate the distance is world coordinate of the radius.
            double worldDistance = ExtentHelper.GetWorldDistanceBetweenTwoScreenPoints(Map1.CurrentExtent, clickScreenPoint, clickNextScreenPoint, 850, 750, GeographyUnit.Meter, DistanceUnit.Meter);

            // calculate the buffer which you need.
            MultipolygonShape clickArea = clickWorldPosition.Buffer(worldDistance, GeographyUnit.Meter, DistanceUnit.Meter);

            ShapeFileFeatureLayer Lyr_Access_Point = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays[0]).Layers["Lyr_Access_Point"];
            try
            {
                Lyr_Access_Point.Open();
                Collection<Feature> features = Lyr_Access_Point.QueryTools.GetFeaturesIntersecting(clickArea, ReturningColumnsType.AllColumns);

                if (features.Count > 0)
                {
                    for (int i = 0; i < features.Count; i++)
                    {
                        //callbackResult = features[0].ColumnValues["Type_Name"];
                        sb.AppendLine(features[i].ColumnValues["Type_Name"]);
                    }
                }

                ShapeFileFeatureLayer lyr_lines_FS_LD = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays[0]).Layers["Lyr_FS_LD"];
                lyr_lines_FS_LD.Open();
                Collection<Feature> features1 = lyr_lines_FS_LD.QueryTools.GetFeaturesIntersecting(clickArea, ReturningColumnsType.AllColumns);

                if (features1.Count > 0)
                {
                    for (int i = 0; i < features1.Count; i++)
                    {

                        //callbackResult = features1[0].ColumnValues["Name"];
                        sb.AppendLine(features1[i].ColumnValues["Name"]);
                    }
                }
            }
            catch (Exception ex)
            {
                Response.Write(ex.Message);
            }

            callbackResult = sb.ToString();
        }

        #endregion
}
